/*
 * This file is part of the QPxTool project.
 * Copyright (C) 2005-2006 Gennady "ShultZ" Kozlov <qpxtool@mail.ru>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */

#define VERSION			"0.6.0.9"
#define LIBVER_MIN_TRANSPORT	0x00000600
#define LIBVER_MIN_SCAN		0x00000600
#define LIBVER_MIN_PLEXTOR	0x00000600
#define LIBVER_MIN_PIONEER	0x00000600
